@@ -1,9 +1,10 @@
 package HTML::FormFu::Constraint::CallbackOnce;
 
-use strict;
-use base 'HTML::FormFu::Constraint';
+use Moose;
+use MooseX::Attribute::Chained;
+extends 'HTML::FormFu::Constraint';
 
-__PACKAGE__->mk_item_accessors(qw( callback ));
+has callback => ( is => 'rw', traits => ['Chained'] );
 
 sub process {
     my ( $self, $params ) = @_;
@@ -25,6 +26,8 @@ sub process {
         } );
 }
 
+__PACKAGE__->meta->make_immutable;
+
 1;
 
 __END__
@@ -79,3 +82,5 @@ Carl Franks C<cfranks@cpan.org>
 
 This library is free software, you can redistribute it and/or modify it under
 the same terms as Perl itself.
+
+=cut
