@@ -1,7 +1,7 @@
 package HTML::FormFu::Constraint::SingleValue;
 
-use strict;
-use base 'HTML::FormFu::Constraint';
+use Moose;
+extends 'HTML::FormFu::Constraint';
 
 sub constrain_values {
     my ( $self, $values ) = @_;
@@ -13,6 +13,8 @@ sub constrain_value {
     return 1;
 }
 
+__PACKAGE__->meta->make_immutable;
+
 1;
 
 __END__
@@ -31,7 +33,7 @@ This constraint doesn't honour the C<not()> value.
 
 Is a sub-class of, and inherits methods from L<HTML::FormFu::Constraint>
 
-L<HTML::FormFu::FormFu>
+L<HTML::FormFu>
 
 =head1 AUTHOR
 
@@ -41,3 +43,5 @@ Carl Franks C<cfranks@cpan.org>
 
 This library is free software, you can redistribute it and/or modify it under
 the same terms as Perl itself.
+
+=cut
