@@ -1,17 +1,20 @@
 package HTML::FormFu::Element::Button;
+use Moose;
 
-use strict;
-use base 'HTML::FormFu::Element::_Input';
-use Class::C3;
+extends 'HTML::FormFu::Element';
 
-sub new {
-    my $self = shift->next::method(@_);
+with 'HTML::FormFu::Role::Element::Input';
 
-    $self->field_type('button');
-    $self->retain_default(1);
+after BUILD => sub {
+    my ( $self, $args ) = @_;
 
-    return $self;
-}
+    $self->field_type(    'button' );
+    $self->force_default( 1 );
+    
+    return;
+};
+
+__PACKAGE__->meta->make_immutable;
 
 1;
 
@@ -40,7 +43,7 @@ L<HTML::FormFu::Element::_Input>,
 L<HTML::FormFu::Element::_Field>, 
 L<HTML::FormFu::Element>
 
-L<HTML::FormFu::FormFu>
+L<HTML::FormFu>
 
 =head1 AUTHOR
 
@@ -50,3 +53,5 @@ Carl Franks, C<cfranks@cpan.org>
 
 This library is free software, you can redistribute it and/or modify it under
 the same terms as Perl itself.
+
+=cut
