@@ -1,16 +1,17 @@
 package HTML::FormFu::Element::Submit;
+use Moose;
 
-use strict;
-use base 'HTML::FormFu::Element::Button';
-use Class::C3;
+extends 'HTML::FormFu::Element::Button';
 
-sub new {
-    my $self = shift->next::method(@_);
+after BUILD => sub {
+    my $self = shift;
 
     $self->field_type('submit');
 
-    return $self;
-}
+    return;
+};
+
+__PACKAGE__->meta->make_immutable;
 
 1;
 
@@ -30,10 +31,6 @@ Submit button form field.
 
 =head1 METHODS
 
-=head1 non_block
-
-See L<HTML::FormFu::Elements::_Field/non_block> for details.
-
 =head1 SEE ALSO
 
 Is a sub-class of, and inherits methods from 
@@ -42,7 +39,7 @@ L<HTML::FormFu::Element::_Input>,
 L<HTML::FormFu::Element::_Field>, 
 L<HTML::FormFu::Element>
 
-L<HTML::FormFu::FormFu>
+L<HTML::FormFu>
 
 =head1 AUTHOR
 
@@ -52,3 +49,5 @@ Carl Franks, C<cfranks@cpan.org>
 
 This library is free software, you can redistribute it and/or modify it under
 the same terms as Perl itself.
+
+=cut
