@@ -1,6 +1,8 @@
 package HTML::FormFu::Exception::Constraint;
 
-use base 'HTML::FormFu::Exception::Input';
+
+use Moose;
+extends 'HTML::FormFu::Exception::Input';
 
 sub stage {
     return 'constraint';
@@ -10,4 +12,6 @@ sub constraint {
     return shift->processor(@_);
 }
 
+__PACKAGE__->meta->make_immutable;
+
 1;
