@@ -1,7 +1,7 @@
 package HTML::FormFu::Filter::UpperCase;
 
-use strict;
-use base 'HTML::FormFu::Filter';
+use Moose;
+extends 'HTML::FormFu::Filter';
 
 sub filter {
     my ( $self, $value ) = @_;
@@ -11,13 +11,15 @@ sub filter {
     return uc $value;
 }
 
+__PACKAGE__->meta->make_immutable;
+
 1;
 
 __END__
 
 =head1 NAME
 
-HTML::FormFu::Filter::UpperCase
+HTML::FormFu::Filter::UpperCase - filter transforming to upper case
 
 =head1 DESCRIPTION
 
