@@ -1,7 +1,8 @@
 package HTML::FormFu::I18N::it;
-use strict;
+use utf8;
 
-use base qw( HTML::FormFu::I18N );
+use Moose;
+extends 'HTML::FormFu::I18N';
 
 our %Lexicon = (
     form_error_message =>
@@ -42,4 +43,6 @@ our %Lexicon = (
     form_transformer_imager => 'Impossibile elaborare il file dell\'immagine',
 );
 
+__PACKAGE__->meta->make_immutable( inline_constructor => 0 );
+
 1;
