@@ -1,7 +1,7 @@
 package HTML::FormFu::QueryType::CGI::Simple;
+use Moose;
 
-use strict;
-use base 'HTML::FormFu::QueryType::CGI';
+extends 'HTML::FormFu::QueryType::CGI';
 
 sub parse_uploads {
     my ( $class, $form, $name ) = @_;
@@ -43,6 +43,8 @@ sub fh {
     return $self->form->query->upload( $self->filename );
 }
 
+__PACKAGE__->meta->make_immutable;
+
 1;
 
 __END__
@@ -82,7 +84,7 @@ Inherited, see L<HTML::FormFu::QueryType::CGI/type> for details.
 Is a sub-class of, and inherits methods from 
 L<HTML::FormFu::QueryType::CGI>, L<HTML::FormFu::Upload>
 
-L<HTML::FormFu::FormFu>, L<HTML::FormFu::Element::File>
+L<HTML::FormFu>, L<HTML::FormFu::Element::File>
 
 =head1 AUTHOR
 
@@ -92,3 +94,5 @@ Carl Franks, C<cfranks@cpan.org>
 
 This library is free software, you can redistribute it and/or modify it under
 the same terms as Perl itself.
+
+=cut
