@@ -1,9 +1,10 @@
 package HTML::FormFu::Transformer::Callback;
 
-use strict;
-use base 'HTML::FormFu::Transformer';
+use Moose;
+use MooseX::Attribute::Chained;
+extends 'HTML::FormFu::Transformer';
 
-__PACKAGE__->mk_item_accessors(qw( callback ));
+has callback => ( is => 'rw', traits => ['Chained'] );
 
 sub transformer {
     my ( $self, $value, $params ) = @_;
@@ -17,6 +18,8 @@ sub transformer {
     return $return;
 }
 
+__PACKAGE__->meta->make_immutable;
+
 1;
 
 __END__
@@ -65,3 +68,5 @@ Carl Franks C<cfranks@cpan.org>
 
 This library is free software, you can redistribute it and/or modify it under
 the same terms as Perl itself.
+
+=cut
